==> oci-java-sdk-shaded-full-3.40.0-sources.jar: com/oracle/bmc/datasafe/requests/UpdateTargetAlertPolicyAssociationRequest.java <==
/**
 * Copyright (c) 2016, 2024, Oracle and/or its affiliates.  All rights reserved.
 * This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.
 */
package com.oracle.bmc.datasafe.requests;

import com.oracle.bmc.datasafe.model.*;
/**
 * <b>Example: </b>Click <a
 * href="https://docs.cloud.oracle.com/en-us/iaas/tools/java-sdk-examples/3.40.0/datasafe/UpdateTargetAlertPolicyAssociationExample.java.html"
 * target="_blank" rel="noopener noreferrer">here</a> to see how to use
 * UpdateTargetAlertPolicyAssociationRequest.
 */
@jakarta.annotation.Generated(value = "OracleSDKGenerator", comments = "API Version: 20181201")
public class UpdateTargetAlertPolicyAssociationRequest
        extends com.oracle.bmc.requests.BmcRequest<
                com.oracle.bmc.datasafe.model.UpdateTargetAlertPolicyAssociationDetails> {

    /** The OCID of the target-alert policy association. */
    private String targetAlertPolicyAssociationId;

    /** The OCID of the target-alert policy association. */
    public String getTargetAlertPolicyAssociationId() {
        return targetAlertPolicyAssociationId;
    }
    /** The details used to update the target-alert policy association. */
    private com.oracle.bmc.datasafe.model.UpdateTargetAlertPolicyAssociationDetails
            updateTargetAlertPolicyAssociationDetails;

    /** The details used to update the target-alert policy association. */
    public com.oracle.bmc.datasafe.model.UpdateTargetAlertPolicyAssociationDetails
            getUpdateTargetAlertPolicyAssociationDetails() {
        return updateTargetAlertPolicyAssociationDetails;
    }
    /**
     * For optimistic concurrency control. In the PUT or DELETE call for a resource, set the
     * if-match parameter to the value of the etag from a previous GET or POST response for that
     * resource. The resource will be updated or deleted only if the etag you provide matches the
     * resource's current etag value.
     */
    private String ifMatch;

    /**
     * For optimistic concurrency control. In the PUT or DELETE call for a resource, set the
     * if-match parameter to the value of the etag from a previous GET or POST response for that
     * resource. The resource will be updated or deleted only if the etag you provide matches the
     * resource's current etag value.
     */
    public String getIfMatch() {
        return ifMatch;
    }
    /** Unique identifier for the request. */
    private String opcRequestId;

    /** Unique identifier for the request. */
    public String getOpcRequestId() {
        return opcRequestId;
    }

    /**
     * Alternative accessor for the body parameter.
     *
     * @return body parameter
     */
    @Override
    @com.oracle.bmc.InternalSdk
    public com.oracle.bmc.datasafe.model.UpdateTargetAlertPolicyAssociationDetails getBody$() {
        return updateTargetAlertPolicyAssociationDetails;
    }

    public static class Builder
            implements com.oracle.bmc.requests.BmcRequest.Builder<
                    UpdateTargetAlertPolicyAssociationRequest,
                    com.oracle.bmc.datasafe.model.UpdateTargetAlertPolicyAssociationDetails> {
        private com.oracle.bmc.http.client.RequestInterceptor invocationCallback = null;
        private com.oracle.bmc.retrier.RetryConfiguration retryConfiguration = null;

        /** The OCID of the target-alert policy association. */
        private String targetAlertPolicyAssociationId = null;

        /**
         * The OCID of the target-alert policy association.
         *
         * @param targetAlertPolicyAssociationId the value to set
         * @return this builder instance
         */
        public Builder targetAlertPolicyAssociationId(String targetAlertPolicyAssociationId) {
            this.targetAlertPolicyAssociationId = targetAlertPolicyAssociationId;
            return this;
        }

        /** The details used to update the target-alert policy association. */
        private com.oracle.bmc.datasafe.model.UpdateTargetAlertPolicyAssociationDetails
                updateTargetAlertPolicyAssociationDetails = null;

        /**
         * The details used to update the target-alert policy association.
         *
         * @param updateTargetAlertPolicyAssociationDetails the value to set
         * @return this builder instance
         */
        public Builder updateTargetAlertPolicyAssociationDetails(
                com.oracle.bmc.datasafe.model.UpdateTargetAlertPolicyAssociationDetails
                        updateTargetAlertPolicyAssociationDetails) {
            this.updateTargetAlertPolicyAssociationDetails =
                    updateTargetAlertPolicyAssociationDetails;
            return this;
        }

        /**
         * For optimistic concurrency control. In the PUT or DELETE call for a resource, set the
         * if-match parameter to the value of the etag from a previous GET or POST response for that
         * resource. The resource will be updated or deleted only if the etag you provide matches
         * the resource's current etag value.
         */
        private String ifMatch = null;

        /**
         * For optimistic concurrency control. In the PUT or DELETE call for a resource, set the
         * if-match parameter to the value of the etag from a previous GET or POST response for that
         * resource. The resource will be updated or deleted only if the etag you provide matches
         * the resource's current etag value.
         *
         * @param ifMatch the value to set
         * @return this builder instance
         */
        public Builder ifMatch(String ifMatch) {
            this.ifMatch = ifMatch;
            return this;
        }

        /** Unique identifier for the request. */
        private String opcRequestId = null;

        /**
         * Unique identifier for the request.
         *
         * @param opcRequestId the value to set
         * @return this builder instance
         */
        public Builder opcRequestId(String opcRequestId) {
            this.opcRequestId = opcRequestId;
            return this;
        }

        /**
         * Set the invocation callback for the request to be built.
         *
         * @param invocationCallback the invocation callback to be set for the request
         * @return this builder instance
         */
        public Builder invocationCallback(
                com.oracle.bmc.http.client.RequestInterceptor invocationCallback) {
            this.invocationCallback = invocationCallback;
            return this;
        }

        /**
         * Set the retry configuration for the request to be built.
         *
         * @param retryConfiguration the retry configuration to be used for the request
         * @return this builder instance
         */
        public Builder retryConfiguration(
                com.oracle.bmc.retrier.RetryConfiguration retryConfiguration) {
            this.retryConfiguration = retryConfiguration;
            return this;
        }

        /**
         * Copy method to populate the builder with values from the given instance.
         *
         * @return this builder instance
         */
        public Builder copy(UpdateTargetAlertPolicyAssociationRequest o) {
            targetAlertPolicyAssociationId(o.getTargetAlertPolicyAssociationId());
            updateTargetAlertPolicyAssociationDetails(
                    o.getUpdateTargetAlertPolicyAssociationDetails());
            ifMatch(o.getIfMatch());
            opcRequestId(o.getOpcRequestId());
            invocationCallback(o.getInvocationCallback());
            retryConfiguration(o.getRetryConfiguration());
            return this;
        }

        /**
         * Build the instance of UpdateTargetAlertPolicyAssociationRequest as configured by this
         * builder
         *
         * <p>Note that this method takes calls to {@link
         * Builder#invocationCallback(com.oracle.bmc.http.client.RequestInterceptor)} into account,
         * while the method {@link Builder#buildWithoutInvocationCallback} does not.
         *
         * <p>This is the preferred method to build an instance.
         *
         * @return instance of UpdateTargetAlertPolicyAssociationRequest
         */
        public UpdateTargetAlertPolicyAssociationRequest build() {
            UpdateTargetAlertPolicyAssociationRequest request = buildWithoutInvocationCallback();
            request.setInvocationCallback(invocationCallback);
            request.setRetryConfiguration(retryConfiguration);
            return request;
        }

        /**
         * Alternative setter for the body parameter.
         *
         * @param body the body parameter
         * @return this builder instance
         */
        @com.oracle.bmc.InternalSdk
        public Builder body$(
                com.oracle.bmc.datasafe.model.UpdateTargetAlertPolicyAssociationDetails body) {
            updateTargetAlertPolicyAssociationDetails(body);
            return this;
        }

        /**
         * Build the instance of UpdateTargetAlertPolicyAssociationRequest as configured by this
         * builder
         *
         * <p>Note that this method does not take calls to {@link
         * Builder#invocationCallback(com.oracle.bmc.http.client.RequestInterceptor)} into account,
         * while the method {@link Builder#build} does
         *
         * @return instance of UpdateTargetAlertPolicyAssociationRequest
         */
        public UpdateTargetAlertPolicyAssociationRequest buildWithoutInvocationCallback() {
            UpdateTargetAlertPolicyAssociationRequest request =
                    new UpdateTargetAlertPolicyAssociationRequest();
            request.targetAlertPolicyAssociationId = targetAlertPolicyAssociationId;
            request.updateTargetAlertPolicyAssociationDetails =
                    updateTargetAlertPolicyAssociationDetails;
            request.ifMatch = ifMatch;
            request.opcRequestId = opcRequestId;
            return request;
            // new UpdateTargetAlertPolicyAssociationRequest(targetAlertPolicyAssociationId,
            // updateTargetAlertPolicyAssociationDetails, ifMatch, opcRequestId);
        }
    }

    /**
     * Return an instance of {@link Builder} that allows you to modify request properties.
     *
     * @return instance of {@link Builder} that allows you to modify request properties.
     */
    public Builder toBuilder() {
        return new Builder()
                .targetAlertPolicyAssociationId(targetAlertPolicyAssociationId)
                .updateTargetAlertPolicyAssociationDetails(
                        updateTargetAlertPolicyAssociationDetails)
                .ifMatch(ifMatch)
                .opcRequestId(opcRequestId);
    }

    /**
     * Return a new builder for this request object.
     *
     * @return builder for the request object
     */
    public static Builder builder() {
        return new Builder();
    }

    @Override
    public String toString() {
        java.lang.StringBuilder sb = new java.lang.StringBuilder();
        sb.append("(");
        sb.append("super=").append(super.toString());
        sb.append(",targetAlertPolicyAssociationId=")
                .append(String.valueOf(this.targetAlertPolicyAssociationId));
        sb.append(",updateTargetAlertPolicyAssociationDetails=")
                .append(String.valueOf(this.updateTargetAlertPolicyAssociationDetails));
        sb.append(",ifMatch=").append(String.valueOf(this.ifMatch));
        sb.append(",opcRequestId=").append(String.valueOf(this.opcRequestId));
        sb.append(")");
        return sb.toString();
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (!(o instanceof UpdateTargetAlertPolicyAssociationRequest)) {
            return false;
        }

        UpdateTargetAlertPolicyAssociationRequest other =
                (UpdateTargetAlertPolicyAssociationRequest) o;
        return super.equals(o)
                && java.util.Objects.equals(
                        this.targetAlertPolicyAssociationId, other.targetAlertPolicyAssociationId)
                && java.util.Objects.equals(
                        this.updateTargetAlertPolicyAssociationDetails,
                        other.updateTargetAlertPolicyAssociationDetails)
                && java.util.Objects.equals(this.ifMatch, other.ifMatch)
                && java.util.Objects.equals(this.opcRequestId, other.opcRequestId);
    }

    @Override
    public int hashCode() {
        final int PRIME = 59;
        int result = super.hashCode();
        result =
                (result * PRIME)
                        + (this.targetAlertPolicyAssociationId == null
                                ? 43
                                : this.targetAlertPolicyAssociationId.hashCode());
        result =
                (result * PRIME)
                        + (this.updateTargetAlertPolicyAssociationDetails == null
                                ? 43
                                : this.updateTargetAlertPolicyAssociationDetails.hashCode());
        result = (result * PRIME) + (this.ifMatch == null ? 43 : this.ifMatch.hashCode());
        result = (result * PRIME) + (this.opcRequestId == null ? 43 : this.opcRequestId.hashCode());
        return result;
    }
}

==> oci-java-sdk-shaded-full-3.48.0-sources.jar: com/oracle/bmc/datasafe/requests/UpdateTargetAlertPolicyAssociationRequest.java <==
/**
 * Copyright (c) 2016, 2024, Oracle and/or its affiliates.  All rights reserved.
 * This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.
 */
package com.oracle.bmc.datasafe.requests;

import com.oracle.bmc.datasafe.model.*;
/**
 * <b>Example: </b>Click <a
 * href="https://docs.cloud.oracle.com/en-us/iaas/tools/java-sdk-examples/latest/datasafe/UpdateTargetAlertPolicyAssociationExample.java.html"
 * target="_blank" rel="noopener noreferrer">here</a> to see how to use
 * UpdateTargetAlertPolicyAssociationRequest.
 */
@jakarta.annotation.Generated(value = "OracleSDKGenerator", comments = "API Version: 20181201")
public class UpdateTargetAlertPolicyAssociationRequest
        extends com.oracle.bmc.requests.BmcRequest<
                com.oracle.bmc.datasafe.model.UpdateTargetAlertPolicyAssociationDetails> {

    /** The OCID of the target-alert policy association. */
    private String targetAlertPolicyAssociationId;

    /** The OCID of the target-alert policy association. */
    public String getTargetAlertPolicyAssociationId() {
        return targetAlertPolicyAssociationId;
    }
    /** The details used to update the target-alert policy association. */
    private com.oracle.bmc.datasafe.model.UpdateTargetAlertPolicyAssociationDetails
            updateTargetAlertPolicyAssociationDetails;

    /** The details used to update the target-alert policy association. */
    public com.oracle.bmc.datasafe.model.UpdateTargetAlertPolicyAssociationDetails
            getUpdateTargetAlertPolicyAssociationDetails() {
        return updateTargetAlertPolicyAssociationDetails;
    }
    /**
     * For optimistic concurrency control. In the PUT or DELETE call for a resource, set the
     * if-match parameter to the value of the etag from a previous GET or POST response for that
     * resource. The resource will be updated or deleted only if the etag you provide matches the
     * resource's current etag value.
     */
    private String ifMatch;

    /**
     * For optimistic concurrency control. In the PUT or DELETE call for a resource, set the
     * if-match parameter to the value of the etag from a previous GET or POST response for that
     * resource. The resource will be updated or deleted only if the etag you provide matches the
     * resource's current etag value.
     */
    public String getIfMatch() {
        return ifMatch;
    }
    /** Unique identifier for the request. */
    private String opcRequestId;

    /** Unique identifier for the request. */
    public String getOpcRequestId() {
        return opcRequestId;
    }

    /**
     * Alternative accessor for the body parameter.
     *
     * @return body parameter
     */
    @Override
    @com.oracle.bmc.InternalSdk
    public com.oracle.bmc.datasafe.model.UpdateTargetAlertPolicyAssociationDetails getBody$() {
        return updateTargetAlertPolicyAssociationDetails;
    }

    public static class Builder
            implements com.oracle.bmc.requests.BmcRequest.Builder<
                    UpdateTargetAlertPolicyAssociationRequest,
                    com.oracle.bmc.datasafe.model.UpdateTargetAlertPolicyAssociationDetails> {
        private com.oracle.bmc.http.client.RequestInterceptor invocationCallback = null;
        private com.oracle.bmc.retrier.RetryConfiguration retryConfiguration = null;

        /** The OCID of the target-alert policy association. */
        private String targetAlertPolicyAssociationId = null;

        /**
         * The OCID of the target-alert policy association.
         *
         * @param targetAlertPolicyAssociationId the value to set
         * @return this builder instance
         */
        public Builder targetAlertPolicyAssociationId(String targetAlertPolicyAssociationId) {
            this.targetAlertPolicyAssociationId = targetAlertPolicyAssociationId;
            return this;
        }

        /** The details used to update the target-alert policy association. */
        private com.oracle.bmc.datasafe.model.UpdateTargetAlertPolicyAssociationDetails
                updateTargetAlertPolicyAssociationDetails = null;

        /**
         * The details used to update the target-alert policy association.
         *
         * @param updateTargetAlertPolicyAssociationDetails the value to set
         * @return this builder instance
         */
        public Builder updateTargetAlertPolicyAssociationDetails(
                com.oracle.bmc.datasafe.model.UpdateTargetAlertPolicyAssociationDetails
                        updateTargetAlertPolicyAssociationDetails) {
            this.updateTargetAlertPolicyAssociationDetails =
                    updateTargetAlertPolicyAssociationDetails;
            return this;
        }

        /**
         * For optimistic concurrency control. In the PUT or DELETE call for a resource, set the
         * if-match parameter to the value of the etag from a previous GET or POST response for that
         * resource. The resource will be updated or deleted only if the etag you provide matches
         * the resource's current etag value.
         */
        private String ifMatch = null;

        /**
         * For optimistic concurrency control. In the PUT or DELETE call for a resource, set the
         * if-match parameter to the value of the etag from a previous GET or POST response for that
         * resource. The resource will be updated or deleted only if the etag you provide matches
         * the resource's current etag value.
         *
         * @param ifMatch the value to set
         * @return this builder instance
         */
        public Builder ifMatch(String ifMatch) {
            this.ifMatch = ifMatch;
            return this;
        }

        /** Unique identifier for the request. */
        private String opcRequestId = null;

        /**
         * Unique identifier for the request.
         *
         * @param opcRequestId the value to set
         * @return this builder instance
         */
        public Builder opcRequestId(String opcRequestId) {
            this.opcRequestId = opcRequestId;
            return this;
        }

        /**
         * Set the invocation callback for the request to be built.
         *
         * @param invocationCallback the invocation callback to be set for the request
         * @return this builder instance
         */
        public Builder invocationCallback(
                com.oracle.bmc.http.client.RequestInterceptor invocationCallback) {
            this.invocationCallback = invocationCallback;
            return this;
        }

        /**
         * Set the retry configuration for the request to be built.
         *
         * @param retryConfiguration the retry configuration to be used for the request
         * @return this builder instance
         */
        public Builder retryConfiguration(
                com.oracle.bmc.retrier.RetryConfiguration retryConfiguration) {
            this.retryConfiguration = retryConfiguration;
            return this;
        }

        /**
         * Copy method to populate the builder with values from the given instance.
         *
         * @return this builder instance
         */
        public Builder copy(UpdateTargetAlertPolicyAssociationRequest o) {
            targetAlertPolicyAssociationId(o.getTargetAlertPolicyAssociationId());
            updateTargetAlertPolicyAssociationDetails(
                    o.getUpdateTargetAlertPolicyAssociationDetails());
            ifMatch(o.getIfMatch());
            opcRequestId(o.getOpcRequestId());
            invocationCallback(o.getInvocationCallback());
            retryConfiguration(o.getRetryConfiguration());
            return this;
        }

        /**
         * Build the instance of UpdateTargetAlertPolicyAssociationRequest as configured by this
         * builder
         *
         * <p>Note that this method takes calls to {@link
         * Builder#invocationCallback(com.oracle.bmc.http.client.RequestInterceptor)} into account,
         * while the method {@link Builder#buildWithoutInvocationCallback} does not.
         *
         * <p>This is the preferred method to build an instance.
         *
         * @return instance of UpdateTargetAlertPolicyAssociationRequest
         */
        public UpdateTargetAlertPolicyAssociationRequest build() {
            UpdateTargetAlertPolicyAssociationRequest request = buildWithoutInvocationCallback();
            request.setInvocationCallback(invocationCallback);
            request.setRetryConfiguration(retryConfiguration);
            return request;
        }

        /**
         * Alternative setter for the body parameter.
         *
         * @param body the body parameter
         * @return this builder instance
         */
        @com.oracle.bmc.InternalSdk
        public Builder body$(
                com.oracle.bmc.datasafe.model.UpdateTargetAlertPolicyAssociationDetails body) {
            updateTargetAlertPolicyAssociationDetails(body);
            return this;
        }

        /**
         * Build the instance of UpdateTargetAlertPolicyAssociationRequest as configured by this
         * builder
         *
         * <p>Note that this method does not take calls to {@link
         * Builder#invocationCallback(com.oracle.bmc.http.client.RequestInterceptor)} into account,
         * while the method {@link Builder#build} does
         *
         * @return instance of UpdateTargetAlertPolicyAssociationRequest
         */
        public UpdateTargetAlertPolicyAssociationRequest buildWithoutInvocationCallback() {
            UpdateTargetAlertPolicyAssociationRequest request =
                    new UpdateTargetAlertPolicyAssociationRequest();
            request.targetAlertPolicyAssociationId = targetAlertPolicyAssociationId;
            request.updateTargetAlertPolicyAssociationDetails =
                    updateTargetAlertPolicyAssociationDetails;
            request.ifMatch = ifMatch;
            request.opcRequestId = opcRequestId;
            return request;
            // new UpdateTargetAlertPolicyAssociationRequest(targetAlertPolicyAssociationId,
            // updateTargetAlertPolicyAssociationDetails, ifMatch, opcRequestId);
        }
    }

    /**
     * Return an instance of {@link Builder} that allows you to modify request properties.
     *
     * @return instance of {@link Builder} that allows you to modify request properties.
     */
    public Builder toBuilder() {
        return new Builder()
                .targetAlertPolicyAssociationId(targetAlertPolicyAssociationId)
                .updateTargetAlertPolicyAssociationDetails(
                        updateTargetAlertPolicyAssociationDetails)
                .ifMatch(ifMatch)
                .opcRequestId(opcRequestId);
    }

    /**
     * Return a new builder for this request object.
     *
     * @return builder for the request object
     */
    public static Builder builder() {
        return new Builder();
    }

    @Override
    public String toString() {
        java.lang.StringBuilder sb = new java.lang.StringBuilder();
        sb.append("(");
        sb.append("super=").append(super.toString());
        sb.append(",targetAlertPolicyAssociationId=")
                .append(String.valueOf(this.targetAlertPolicyAssociationId));
        sb.append(",updateTargetAlertPolicyAssociationDetails=")
                .append(String.valueOf(this.updateTargetAlertPolicyAssociationDetails));
        sb.append(",ifMatch=").append(String.valueOf(this.ifMatch));
        sb.append(",opcRequestId=").append(String.valueOf(this.opcRequestId));
        sb.append(")");
        return sb.toString();
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (!(o instanceof UpdateTargetAlertPolicyAssociationRequest)) {
            return false;
        }

        UpdateTargetAlertPolicyAssociationRequest other =
                (UpdateTargetAlertPolicyAssociationRequest) o;
        return super.equals(o)
                && java.util.Objects.equals(
                        this.targetAlertPolicyAssociationId, other.targetAlertPolicyAssociationId)
                && java.util.Objects.equals(
                        this.updateTargetAlertPolicyAssociationDetails,
                        other.updateTargetAlertPolicyAssociationDetails)
                && java.util.Objects.equals(this.ifMatch, other.ifMatch)
                && java.util.Objects.equals(this.opcRequestId, other.opcRequestId);
    }

    @Override
    public int hashCode() {
        final int PRIME = 59;
        int result = super.hashCode();
        result =
                (result * PRIME)
                        + (this.targetAlertPolicyAssociationId == null
                                ? 43
                                : this.targetAlertPolicyAssociationId.hashCode());
        result =
                (result * PRIME)
                        + (this.updateTargetAlertPolicyAssociationDetails == null
                                ? 43
                                : this.updateTargetAlertPolicyAssociationDetails.hashCode());
        result = (result * PRIME) + (this.ifMatch == null ? 43 : this.ifMatch.hashCode());
        result = (result * PRIME) + (this.opcRequestId == null ? 43 : this.opcRequestId.hashCode());
        return result;
    }
}
